@@ -170,19 +170,23 @@ class Webapp():
         """
         self.__webapp.ClickBox(fields, contents_list, select_all, grid_number)
 
-    def ClickFolder(self, item):
+    def ClickFolder(self, item, position=1):
         """
         Clicks on folder elements on the screen.
 
         :param folder_name: Which folder item should be clicked.
         :type folder_name: str
+        :param position: In case of two or more folders with the same name in the screen, you could choose by position in order
+        :type position: int
 
         Usage:
 
         >>> # Calling the method:
         >>> oHelper.ClickFolder("Folder1")
+        >>> # Second folder named as Folder1 in the same screen
+        >>> oHelper.ClickFolder("Folder1", position=2)
         """
-        self.__webapp.ClickFolder(item)
+        self.__webapp.ClickFolder(item, position)
 
     def ClickGridCell(self, column, row=1, grid_number=1):
         """
@@ -460,7 +464,7 @@ class Webapp():
         """
         self.__webapp.SetupTSS(initial_program, environment)
 
-    def SearchBrowse(self, term, key=None, identifier=None, index=False):
+    def SearchBrowse(self, term, key=None, identifier=None, index=False, column=None):
         """
         Searchs a term on Protheus Webapp.
 
@@ -478,6 +482,8 @@ class Webapp():
         :type identifier: str
         :param index: Whether the key is an index or not. - **Default:** False
         :type index: bool
+        :param column: The search column to be chosen on the search dropdown. - **Default:** None
+        :type column: str
 
         Usage:
 
@@ -496,8 +502,16 @@ class Webapp():
         >>> #------------------------------------------------------------------------
         >>> # To search using an index instead of name for the search key:
         >>> oHelper.SearchBrowse("D MG 001", key=2, index=True)
+        >>> #------------------------------------------------------------------------
+        >>> # To search using the first search box and a chosen column:
+        >>> oHelper.SearchBrowse("D MG 001", column="Nome")
+        >>> #------------------------------------------------------------------------
+        >>> #------------------------------------------------------------------------
+        >>> # To search using the first search box and a chosen columns:
+        >>> oHelper.SearchBrowse("D MG 001", column="Nome, Filial*, ColumnX, AnotherColumnY")
+        >>> #------------------------------------------------------------------------
         """
-        self.__webapp.SearchBrowse(term, key, identifier, index)
+        self.__webapp.SearchBrowse(term, key, identifier, index, column)
 
     def SetBranch(self, branch):
         """
@@ -686,8 +700,12 @@ class Webapp():
         >>> # Calling method to input value on a field that is on the second grid of the screen:
         >>> oHelper.SetValue("Order", "000001", grid=True, grid_number=2)
         >>> oHelper.LoadGrid()
+        >>> #-----------------------------------------
+        >>> # Calling method to input value on a field that is a grid (2) *Will not attempt to verify the entered value. Run only once.* :
+        >>> oHelper.SetValue("Order", "000001", grid=True, grid_number=2, check_value = False)
+        >>> oHelper.LoadGrid()
         """
-        self.__webapp.SetValue(field, value, grid, grid_number, ignore_case, row, name_attr, position)
+        self.__webapp.SetValue(field, value, grid, grid_number, ignore_case, row, name_attr, position, check_value)
 
     def Setup(self, initial_program,  date="", group="99", branch="01", module=""):
         """
